@@ -18,7 +18,7 @@
 // along with this program ; if not, write to the Free Software
 // Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA
 //
-// $Id: FederationManagement.cc,v 3.16.2.1 2007/01/30 10:04:22 rousse Exp $
+// $Id: FederationManagement.cc,v 3.22 2007/04/24 15:10:31 erk Exp $
 // ----------------------------------------------------------------------------
 
 #include <config.h>
@@ -36,6 +36,7 @@
 #include <assert.h>
 
 using std::list ;
+using std::string ;
 
 namespace certi {
 namespace rtia {
@@ -44,10 +45,11 @@ static pdCDebug D("RTIA_FM", "(RTIA FM) ");
 
 // ----------------------------------------------------------------------------
 //! FederationManagement.
-FederationManagement::FederationManagement(Communications *GC)
+  FederationManagement::FederationManagement(Communications *GC, Statistics* stat)
     : savingState(false), restoringState(false)
 {
     comm = GC ;
+    this->stat = stat ;
     tm = NULL ;
 
     _numero_federation = 0 ;
@@ -60,6 +62,7 @@ FederationManagement::FederationManagement(Communications *GC)
 
     _nom_federation[0] = 0 ;
     _nom_federe[0] = 0 ;
+    _FEDid[0] = 0 ;
 }
 
 // ----------------------------------------------------------------------------
@@ -95,6 +98,9 @@ void
 FederationManagement::
 createFederationExecution(const char *theName,
                           TypeException &e)
+         throw ( FederationExecutionAlreadyExists,
+                 CouldNotOpenFED,
+                 RTIinternalError)
 {
     NetworkMessage requete, reponse ;
 
@@ -109,6 +115,7 @@ createFederationExecution(const char *theName,
     if (e == e_NO_EXCEPTION) {
         requete.type = NetworkMessage::CREATE_FEDERATION_EXECUTION ;
         strcpy(requete.federationName, theName);
+        strcpy(requete.FEDid, _FEDid) ;
 
         comm->sendMessage(&requete);
 
@@ -121,6 +128,11 @@ createFederationExecution(const char *theName,
             _est_createur_federation = true ;
             D.Out(pdInit, "est createur");
         }
+        else if (reponse.exception == e_CouldNotOpenFED)
+            {
+            e = reponse.exception;
+            cout << "Could not open FED." << endl;
+            }           
         else {
             e = reponse.exception ;
             D.Out(pdInit, "deja cree");
@@ -177,8 +189,9 @@ joinFederationExecution(const char *Federate,
                         const char *Federation,
                         TypeException &e)
 {
-    NetworkMessage requete, reponse ;
+    NetworkMessage requete, reponse, requeteFED ;
     int i, nb ;
+    char filename[MAX_FEDFILE_NAME_LENGTH] ; // Pour s'en servir pour le nom du fichier temporaire
 
     D.Out(pdInit, "Join Federation %s as %s.", Federation, Federate);
 
@@ -200,11 +213,97 @@ joinFederationExecution(const char *Federate,
 
         comm->sendMessage(&requete);
 
-        // On attend la reponse du RTIG(de n'importe quel federe)
+        // Waiting RTIG answer for FED file opened
+        comm->waitMessage(&reponse, NetworkMessage::GET_FED_FILE, 0);
+
+        if ( reponse.exception != e_NO_EXCEPTION)
+            {
+            // Bad answer from RTIG
+            e = reponse.exception ;
+            }
+        else
+            {
+	    stat->rtiService(NetworkMessage::GET_FED_FILE);
+            // RTIA have to open a new file for working
+            // We have to build a name for working file, name begins by :RTIA
+            strcpy(filename,":RTIA:");
+            // First pid converted in char and added
+            // Then federation name added also
+            // Last file type : fed or xml ?
+            char pid_name[10];
+            sprintf(pid_name,"%d:",getpid());
+            strcat(filename,pid_name); 
+            strcat(filename,Federation);     
+            string filename_RTIG = reponse.FEDid ;
+            int nbcar_filename_RTIG=filename_RTIG.length();        
+            string extension = filename_RTIG.substr(nbcar_filename_RTIG-3,3) ;
+              if ( !strcasecmp(extension.c_str(),"fed") )
+                  {
+                  strcat(filename,".fed");
+                  }
+              else if  ( !strcasecmp(extension.c_str(),"xml") )
+                  {
+                  strcat(filename,".xml");
+                  } 
+              else 
+                  throw CouldNotOpenFED("nor .fed nor .xml"); 
+            // FED filename for working must be stored
+            strcpy(_FEDid,filename) ;              
+            // RTIA opens working file
+            FILE *fdd;
+            if ( (fdd=fopen(filename,"w")) == NULL )
+                throw RTIinternalError("FED file has vanished.") ;
+              
+            // RTIA says RTIG OK for file transfer
+            requeteFED.type = NetworkMessage::GET_FED_FILE ;
+            strcpy(requeteFED.federationName, Federation);
+            strcpy(requeteFED.federateName, Federate);
+            if ( e == e_NO_EXCEPTION)
+                requeteFED.number = 0 ;  // OK for open
+            else
+                requeteFED.number = 1 ;  
+            comm->sendMessage(&requeteFED);
+    
+            // Now read loop from RTIG to get line contents and then write it into file
+            char *file_line = NULL ;
+            unsigned long length=0 ;
+            int num_line = 0 ; // no line read
+            for (;;)
+                {
+                comm->waitMessage(&reponse, NetworkMessage::GET_FED_FILE, 0);
+                if ( reponse.exception != e_NO_EXCEPTION)
+                    {
+                    cout << "Bad answer from RTIG" << endl ;
+                    e = e_RTIinternalError ;
+                    break ;
+                    }
+		stat->rtiService(NetworkMessage::GET_FED_FILE);
+                // Line read
+                num_line++ ;
+                // Check for EOF
+                if ( reponse.number == 0 )
+                    break;
+                assert ( num_line == reponse.number ) ;
+                reponse.handleArraySize = 1 ;
+                file_line = reponse.getValue(0,&length) ;
+                int nbw = fputs(file_line,fdd);
+                file_line = NULL ;
+                // RTIA says OK to RTIG
+                requeteFED.type = NetworkMessage::GET_FED_FILE ;
+                strcpy(requeteFED.federationName, Federation);
+                strcpy(requeteFED.federateName, Federate);
+                requeteFED.number = num_line ;  
+                comm->sendMessage(&requeteFED);            
+                }
+            // close working file
+            fclose(fdd); 
+            }                          
+            
+         // Waiting RTIG answer (from any federate)
         comm->waitMessage(&reponse, NetworkMessage::JOIN_FEDERATION_EXECUTION, 0);
 
-        // Si c'est positif, cette reponse contient le nombre de regulateurs.
-        // On attend alors un message NULL de chacun d'eux.
+        // If OK, regulators number is inside the answer.
+        // Then we except a NULL message from each.
         if (reponse.exception == e_NO_EXCEPTION) {
             strcpy(_nom_federation, Federation);
             strcpy(_nom_federe, Federate);
@@ -330,7 +429,7 @@ FederationManagement::unregisterSynchronization(const char *label,
     // Find if this label has been requested by federate or RTIG.
     list<char *>::iterator i = synchronizationLabels.begin();
     bool exists = false ;
-    for (; i != synchronizationLabels.end(); i++) {
+    for (; i != synchronizationLabels.end(); ++i) {
         if (!strcmp((*i), label)) {
             // Label already pending.
             exists = true ;
@@ -340,8 +439,12 @@ FederationManagement::unregisterSynchronization(const char *label,
     if (!exists)
         e = e_UnknownLabel ;
     else {
-	delete[] *i ;
-	synchronizationLabels.erase(i);
+      /* delete[] *i ;
+       * the label has been allocated using strdup (i.e. malloc-like)
+       * so that we MUST use free (and not delete[]) to free it :))
+       */
+      free(*i);
+      synchronizationLabels.erase(i);
     }
     
     if (!_est_membre_federation)
@@ -640,4 +743,4 @@ FederationManagement::checkFederationRestoring()
 
 }} // namespace certi/rtia
 
-// $Id: FederationManagement.cc,v 3.16.2.1 2007/01/30 10:04:22 rousse Exp $
+// $Id: FederationManagement.cc,v 3.22 2007/04/24 15:10:31 erk Exp $
