@@ -18,7 +18,7 @@
 // along with this program ; if not, write to the Free Software
 // Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA
 //
-// $Id: Federation.cc,v 3.45.2.1 2007/01/22 13:54:51 rousse Exp $
+// $Id: Federation.cc,v 3.52 2007/05/03 15:46:31 rousse Exp $
 // ----------------------------------------------------------------------------
 
 #include <config.h>
@@ -34,7 +34,9 @@
 #include <fstream>
 #include <iostream>
 #include <string.h>
+#include <sys/types.h>
 #include <sys/stat.h>
+#include <unistd.h>
 #include <errno.h>
 
 using std::pair ;
@@ -77,9 +79,10 @@ Federation::Federation(const char *federation_name,
     Federation::Federation(const char *federation_name,
                            Handle federation_handle,
                            SocketServer &socket_server,
-                           AuditFile &audit_server)
+                           AuditFile &audit_server,
+                           const char *FEDid_name)
 #endif
-    throw (CouldNotOpenRID, ErrorReadingRID, MemoryExhausted, SecurityError,
+    throw (CouldNotOpenFED, ErrorReadingRID, MemoryExhausted, SecurityError,
            RTIinternalError)
     : federateHandles(1), objectHandles(1), saveInProgress(false),
       restoreInProgress(false), saveStatus(true), restoreStatus(true),
@@ -87,6 +90,7 @@ Federation::Federation(const char *federation_name,
 
 {
     //    fedparser::FedParser *fed_reader ;
+  struct stat file_stat;
 
 #ifdef FEDERATION_USES_MULTICAST // -----------------
     // Initialize Multicast
@@ -111,6 +115,8 @@ Federation::Federation(const char *federation_name,
     // Default Attribute values
     handle = federation_handle ;
 
+    FEDid = strdup(FEDid_name) ;
+
     D.Out(pdInit, "New Federation created with Handle %d, now reading FOM.",
           handle);
 
@@ -121,43 +127,110 @@ Federation::Federation(const char *federation_name,
     root = new RootObject(server);
 
     cout << "New federation: " << name << endl ;
-    cout << "Looking for .fed file... " ;
 
-    string filename = string(name) + ".fed" ;
+
+    // We should try to open FOM file from different
+    // predefined places:
+    //
+    // 1 - bare filename considered as a path provided through FEDid_name
+    //
+    // 2 - getenv(CERTI_HOME)+"/share/federations"+ FEDid_name
+    //
+    // 3 - default (unix) installation place plus FEDid_name 
+    //     "/usr/local/share/federation/" + FEDid_name
+    //
+    string filename   = string(FEDid) ;
+    bool   filefound  = false;
+    cout << "Looking for FOM file... " << endl ; 
+
+    cout << "   Trying... " << filename;
+    filefound = (0==stat(filename.c_str(),&file_stat));
+
+    if (!filefound) {
+      cout << " --> cannot access." <<endl;
+      filename = "/usr/local/share/federation/"+string(FEDid_name);
+      cout << "   Now trying..." << filename;
+    }
+    filefound = (0==stat(filename.c_str(),&file_stat));
+
+    if (!filefound) {
+      cout << " --> cannot access." <<endl;
+      filename = string(getenv("CERTI_HOME"))+"/share/federations/"+FEDid_name;
+      cout << "   Now trying..." << filename;
+    }
+    filefound = (0==stat(filename.c_str(),&file_stat));
+    
+    if (!filefound) {
+      cout << " --> cannot access." <<endl;
+      cerr << "Next step will fail"<<endl;
+    }
+
+    // now really assign FEDid
+    free(FEDid);
+    FEDid = strdup(filename.c_str());
+
+    // Try to open to verify if file exists
+    FILE *fftry ;
+    if ( (fftry=fopen(FEDid,"r")) == NULL)
+        {
+        cout << "... failed : ";
+        throw CouldNotOpenFED("FED file unknown.");
+        }
+    else
+        {
+        cout << "... opened." << endl ;
+        fclose(fftry) ;
+        }
+
+    int  nbcar_filename = filename.length() ;
+    bool is_a_fed       = false ;
+    bool is_an_xml      = false ;
+    
+    // hope there is a . before fed or xml
+    if ( filename.at(nbcar_filename-4) != '.' )
+        throw CouldNotOpenFED("FED file incorrect filename, cannot find extension (character '.' is missing [or not in reverse 4th place])");
+
+    string extension = filename.substr(nbcar_filename-3,3) ;
+    D.Out(pdTrace,"filename is: %s (extension is <%s>",filename.c_str(),extension.c_str());
+    if ( !strcasecmp(extension.c_str(),"fed") )
+        {
+        is_a_fed = true ;
+        D.Out(pdTrace, "Trying to use .fed file");
+        }
+    else if  ( !strcasecmp(extension.c_str(),"xml") )
+        {
+        is_an_xml = true ;
+        D.Out(pdTrace, "Trying to use .xml file");
+        } 
+    else 
+        throw CouldNotOpenFED("FED file incorrect filename : nor .fed nor .xml file");
+       
     ifstream fdd(filename.c_str());
 
-    if (fdd.is_open()) {
+    if (fdd.is_open())
+        {
 	fdd.close();
-
-        cout << "yes" << endl ;
-	int err = fedparser::build(filename.c_str(), root, verbose);
-	if (err) throw ErrorReadingFED("");
+        if ( is_a_fed )
+            {
+	    int err = fedparser::build(filename.c_str(), root, verbose);
+	    if (err) throw ErrorReadingFED("");
 	    
-        // Retrieve the FED file last modification time(for Audit)
-        struct stat StatBuffer ;
-        char *MTimeBuffer ;
-
-        if (stat(filename.c_str(), &StatBuffer) == 0) {
-            MTimeBuffer = ctime(&StatBuffer.st_mtime);
-            MTimeBuffer[strlen(MTimeBuffer) - 1] = 0 ; // Remove trailing \n
-            server->audit << "(Last modified " << MTimeBuffer << ")" ;
-        }
-        else
-            server->audit << "(could not retrieve last modif time, errno "
-			  << errno << ")." ;
-    }
-    else {
-        cout << "no" << endl ;
-        if (XmlParser::exists()) {
-            cout << "Looking for .xml file... " ;
-
-            filename = string(name) + ".xml" ;
-            fdd.open(filename.c_str());
-
-            if (fdd.is_open()) {
-		fdd.close();
-                cout << "yes" << endl ;
+            // Retrieve the FED file last modification time(for Audit)
+            struct stat StatBuffer ;
+            char *MTimeBuffer ;
 
+            if (stat(filename.c_str(), &StatBuffer) == 0) {
+                MTimeBuffer = ctime(&StatBuffer.st_mtime);
+                MTimeBuffer[strlen(MTimeBuffer) - 1] = 0 ; // Remove trailing \n
+                server->audit << "(Last modified " << MTimeBuffer << ")" ;
+            }
+            else
+                server->audit << "(could not retrieve last modif time, errno "
+		    	  << errno << ")." ;
+            }
+        else if ( is_an_xml )
+            {
+            if (XmlParser::exists()) {
                 XmlParser *parser = new XmlParser(root);
                 server->audit << ", XML File : " << filename.c_str() ;
 
@@ -175,7 +248,7 @@ Federation::Federation(const char *federation_name,
                 delete parser ;
             }
             else {
-                cout << "no" << endl ;
+                cout << "nor fed nor xml" << endl ;
 		throw CouldNotOpenFED("");
 	    }
         }
@@ -189,13 +262,14 @@ Federation::~Federation()
     D.Out(pdInit, "Destroying Federation %d...", handle);
 
     // If there are Federates, delete them all!
-    for (list<Federate *>::const_iterator i = begin(); i != end(); i++) {
-        delete(*i);
-    }
-    clear();
+//     for (list<Federate *>::const_iterator i = begin(); i != end(); i++) {
+//         delete(*i);
+//     }
+//     clear();
 
     // Free local allocations
     free(name);
+    free(FEDid);
     delete root ;
 
     delete server ;
@@ -212,7 +286,7 @@ Federation::~Federation()
 int
 Federation::getNbFederates() const
 {
-    return size();
+    return federates.size();
 }
 
 // ----------------------------------------------------------------------------
@@ -247,6 +321,14 @@ Federation::getNbRegulators() const
     return regulators.size();
 }
 
+// ----------------------------------------------------------------------------
+//! Returns the FEDid name given in 'Create Federation Execution'.
+const char *
+Federation::getFEDid() const
+{
+    return FEDid ;
+}
+
 // ----------------------------------------------------------------------------
 /*! Add the Federate to the Federation, and return its new federate handle.
   MAX_FEDERATE is the maximum number of federates per federation. Also send
@@ -262,13 +344,8 @@ Federation::add(const char *federate_name, SocketTCP *tcp_link)
         throw RTIinternalError("Tried to add NULL federate to federation.");
     }
 
-    if (size() >= MAX_FEDERATE) {
-        D.Out(pdExcept, "Federation %d has too many Federates.", handle);
-        throw RTIinternalError("Too many federates in federation.");
-    }
-
     try {
-        this->getByName(federate_name);
+        getFederate(federate_name);
         throw FederateAlreadyExecutionMember("");
     }
     catch (FederateNotExecutionMember &e) {
@@ -276,8 +353,7 @@ Federation::add(const char *federate_name, SocketTCP *tcp_link)
     }
 
     FederateHandle federate_handle = federateHandles.provide();
-    Federate *federate = new Federate(federate_name, federate_handle);
-    push_front(federate);
+    federates.push_back(Federate(federate_name, federate_handle));
     D.Out(pdInit, "Federate %d joined Federation %d.", federate_handle, handle);
 
     // Send, to the newly added federate, a Null message from each regulating
@@ -316,7 +392,7 @@ Federation::add(const char *federate_name, SocketTCP *tcp_link)
                       " to the new Federate.", (*i).first, message.type);
 
                 message.write(tcp_link);
-                federate->addSynchronizationLabel((*i).first);
+                federates.back().addSynchronizationLabel((*i).first);
             }
         }
     }
@@ -339,14 +415,14 @@ Federation::addConstrained(FederateHandle federate_handle)
            RTIinternalError)
 {
     // It may throw FederateNotExecutionMember
-    Federate *federate = getByHandle(federate_handle);
+    Federate &federate = getFederate(federate_handle);
 
-    if (federate->isConstrained()) {
+    if (federate.isConstrained()) {
         D.Out(pdExcept, "Federate %d already constrained.", federate_handle);
         throw RTIinternalError("Time Regulating already enabled.");
     }
 
-    federate->setConstrained(true);
+    federate.setConstrained(true);
     D.Out(pdTerm, "Federation %d: Federate %d is now constrained.",
           handle, federate_handle);
 }
@@ -364,11 +440,11 @@ Federation::addRegulator(FederateHandle federate_handle, FederationTime time)
            RTIinternalError)
 {
     // It may throw FederateNotExecutionMember
-    Federate *federate = getByHandle(federate_handle);
+    Federate &federate = getFederate(federate_handle);
 
     // It may throw RTIinternalError if Federate was not regulators.
     regulators.insert(federate_handle, time);
-    federate->setRegulator(true);
+    federate.setRegulator(true);
 
     D.Out(pdTerm, "Federation %d: Federate %d is now a regulator(Time=%f).",
           handle, federate_handle, time);
@@ -385,7 +461,7 @@ Federation::addRegulator(FederateHandle federate_handle, FederationTime time)
 }
 
 // ----------------------------------------------------------------------------
-//! Broadcast 'msg' to all Federate except the one whose Handle is 'Except'.
+//! Broadcast 'msg' to all Federate except the specified one
 void
 Federation::broadcastAnyMessage(NetworkMessage *msg,
                                 FederateHandle except_federate)
@@ -394,13 +470,13 @@ Federation::broadcastAnyMessage(NetworkMessage *msg,
 
     // Broadcast the message 'msg' to all Federates in the Federation
     // except to Federate whose Handle is 'Except_Federate'.
-    for (list<Federate *>::const_iterator i = begin(); i != end(); i++) {
-        if ((*i)->getHandle() != except_federate) {
+    for (FederateList::const_iterator i = federates.begin(); i != federates.end(); ++i) {
+        if (i->getHandle() != except_federate) {
             try {
 #ifdef HLA_USES_UDP
-                socket = server->getSocketLink((*i)->getHandle(), BEST_EFFORT);
+                socket = server->getSocketLink(i->getHandle(), BEST_EFFORT);
 #else
-                socket = server->getSocketLink((*i)->getHandle());
+                socket = server->getSocketLink(i->getHandle());
 #endif
                 msg->write(socket);
             }
@@ -519,9 +595,9 @@ Federation::registerSynchronization(FederateHandle federate,
                                                                   strdup(tag)));
 
     // Add label to each federate (may throw RTIinternalError).
-    list<Federate *>::iterator j ;
-    for (j = begin(); j != end(); j++) {
-        (*j)->addSynchronizationLabel(label);
+    FederateList::iterator j ;
+    for (j = federates.begin(); j != federates.end(); ++j) {
+        j->addSynchronizationLabel(label);
     }
 
     D[pdTerm] << "Federation " << handle << " is now synchronizing for label "
@@ -570,8 +646,8 @@ Federation::requestFederationSave(FederateHandle the_federate,
     if (saveInProgress)
         throw SaveInProgress("Already in saving state.");
 
-    for (list<Federate *>::iterator j = begin(); j != end(); j++) {
-        (*j)->setSaving(true);
+    for (FederateList::iterator j = federates.begin(); j != federates.end(); ++j) {
+        j->setSaving(true);
     }
 
     saveStatus = true ;
@@ -605,15 +681,15 @@ void
 Federation::federateSaveStatus(FederateHandle the_federate, bool the_status)
     throw (FederateNotExecutionMember)
 {
-    Federate * federate = getByHandle(the_federate);
-    federate->setSaving(false);
+    Federate &federate = getFederate(the_federate);
+    federate.setSaving(false);
 
     if (!the_status)
         saveStatus = false ;
 
     // Verify that all federates save ended (complete or not).
-    for (list<Federate *>::iterator j = begin(); j != end(); j++) {
-        if ((*j)->isSaving())
+    for (FederateList::iterator j = federates.begin(); j != federates.end(); ++j) {
+        if (j->isSaving())
             return ;
     }
 
@@ -689,9 +765,8 @@ Federation::requestFederationRestore(FederateHandle the_federate,
         return ;
 
     // Otherwise...
-    list<Federate *>::iterator j ;
-    for (j = begin(); j != end(); j++) {
-        (*j)->setRestoring(true);
+    for (FederateList::iterator i = federates.begin(); i != federates.end(); ++i) {
+        i->setRestoring(true);
     }
     restoreStatus = true ;
     restoreInProgress = true ;
@@ -711,9 +786,8 @@ Federation::requestFederationRestore(FederateHandle the_federate,
     msg->setLabel(the_label);
     msg->type = NetworkMessage::INITIATE_FEDERATE_RESTORE ;
 
-    list<Federate *>::const_iterator k ;
-    for (k = begin(); k != end(); k++) {
-        msg->federate = (*k)->getHandle();
+    for (FederateList::iterator i = federates.begin(); i != federates.end(); ++i) {
+        msg->federate = i->getHandle();
 
         // send message.
         socket = server->getSocketLink(msg->federate);
@@ -731,16 +805,15 @@ Federation::federateRestoreStatus(FederateHandle the_federate,
                                   bool the_status)
     throw (FederateNotExecutionMember)
 {
-    Federate * federate = getByHandle(the_federate);
-    federate->setRestoring(false);
+    Federate &federate = getFederate(the_federate);
+    federate.setRestoring(false);
 
     if (!the_status)
         restoreStatus = false ;
 
     // Verify that all federates save ended (complete or not).
-    list<Federate *>::iterator j ;
-    for (j = begin(); j != end(); j++) {
-        if ((*j)->isRestoring() == true)
+    for (FederateList::iterator j = federates.begin(); j != federates.end(); ++j) {
+        if (j->isRestoring())
             return ;
     }
 
@@ -763,28 +836,28 @@ Federation::federateRestoreStatus(FederateHandle the_federate,
 }
 
 // ----------------------------------------------------------------------------
-//! Return a pointer of the Federate whose Handle is theHandle, if found.
-Federate*
-Federation::getByHandle(FederateHandle federate_handle) const
+//! Return the Federate whose Handle is theHandle, if found.
+Federate &
+Federation::getFederate(FederateHandle federate_handle)
     throw (FederateNotExecutionMember)
 {
-    for (list<Federate *>::const_iterator i = begin(); i != end(); i++) {
-        if ((*i)->getHandle() == federate_handle)
-            return (*i);
+    for (FederateList::iterator i = federates.begin(); i != federates.end(); ++i) {
+        if (i->getHandle() == federate_handle)
+            return *i ;
     }
 
     throw FederateNotExecutionMember("Federate Handle not found.");
 }
 
 // ----------------------------------------------------------------------------
-//! Return a pointer of the Federate whose Name is theName, if found.
-Federate*
-Federation::getByName(const char *federate_name) const
+//! Return the Federate whose Name is theName, if found.
+Federate &
+Federation::getFederate(const char *federate_name)
     throw (FederateNotExecutionMember)
 {
-    for (list<Federate *>::const_iterator i = begin(); i != end(); i++) {
-        if (strcmp((*i)->getName(), federate_name) == 0)
-            return (*i);
+    for (FederateList::iterator i = federates.begin(); i != federates.end(); ++i) {
+        if (strcmp(i->getName(), federate_name) == 0)
+            return *i ;
     }
 
     throw FederateNotExecutionMember("Federate Name not found.");
@@ -799,7 +872,7 @@ bool
 Federation::empty() const
     throw (FederatesCurrentlyJoined)
 {
-    if (list<Federate *>::empty())
+    if (federates.empty())
         return true ;
     else
         throw FederatesCurrentlyJoined("");
@@ -814,8 +887,8 @@ bool
 Federation::check(FederateHandle federate_handle) const
     throw (FederateNotExecutionMember)
 {
-    for (list<Federate *>::const_iterator i = begin(); i != end(); i++) {
-        if ((*i)->getHandle() == federate_handle)
+    for (FederateList::const_iterator i = federates.begin(); i != federates.end(); ++i) {
+        if (i->getHandle() == federate_handle)
             return true ;
     }
 
@@ -952,12 +1025,11 @@ void
 Federation::remove(FederateHandle federate_handle)
     throw (FederateOwnsAttributes, FederateNotExecutionMember)
 {
-    for (list<Federate *>::iterator i = begin(); i != end(); i++) {
-        if ((*i)->getHandle() == federate_handle) {
+    for (FederateList::iterator i = federates.begin(); i != federates.end(); ++i) {
+        if (i->getHandle() == federate_handle) {
             // BUG: RemoveFederate: Should see if Federate owns attributes
 	    federateHandles.free(federate_handle);
-            delete (*i);
-            erase(i);
+            federates.erase(i);
 
             D.Out(pdInit, "Federation %d: Removed Federate %d.", handle,
                   federate_handle);
@@ -980,14 +1052,14 @@ Federation::removeConstrained(FederateHandle federate_handle)
            RTIinternalError)
 {
     // It may throw FederateNotExecutionMember
-    Federate *federate = getByHandle(federate_handle);
+    Federate &federate = getFederate(federate_handle);
 
-    if (federate->isConstrained() == false) {
+    if (!federate.isConstrained()) {
         D.Out(pdExcept, "Federate %d was not constrained.", federate_handle);
         throw RTIinternalError("Time constrained not enabled.");
     }
 
-    federate->setConstrained(false);
+    federate.setConstrained(false);
     D.Out(pdTerm, "Federation %d: Federate %d is not constrained anymore.",
           handle, federate_handle);
 }
@@ -1002,12 +1074,12 @@ Federation::removeRegulator(FederateHandle federate_handle)
            RTIinternalError)
 {
     // It may throw FederateNotExecutionMember
-    Federate *federate = getByHandle(federate_handle);
+    Federate &federate = getFederate(federate_handle);
 
     // It may throw RTIinternalError if Federate was not regulators.
     regulators.remove(federate_handle);
 
-    federate->setRegulator(false);
+    federate.setRegulator(false);
 
     D.Out(pdTerm, "Federation %d: Federate %d is not a regulator anymore.",
           handle, federate_handle);
@@ -1040,13 +1112,12 @@ Federation::unregisterSynchronization(FederateHandle federate_handle,
         throw RTIinternalError("Bad pause label(null or too long).");
 
     // Set federate synchronized on this label.
-    Federate *federate = getByHandle(federate_handle);
-    federate->removeSynchronizationLabel(label);
+    Federate &federate = getFederate(federate_handle);
+    federate.removeSynchronizationLabel(label);
 
     // Test in every federate is synchronized. Otherwise, quit method.
-    list<Federate *>::iterator j ;
-    for (j = begin(); j != end(); j++) {
-        if ((*j)->isSynchronizationLabel(label) == true)
+    for (FederateList::iterator j = federates.begin(); j != federates.end(); ++j) {
+        if (j->isSynchronizationLabel(label))
             return ;
     }
 
@@ -1169,9 +1240,9 @@ Federation::updateRegulator(FederateHandle federate_handle,
            RTIinternalError)
 {
     // It may throw FederateNotExecutionMember
-    Federate *federate = getByHandle(federate_handle);
+    Federate &federate = getFederate(federate_handle);
 
-    if (federate->isRegulator() == false) {
+    if (!federate.isRegulator()) {
         D.Out(pdExcept, "Federate %d is not a regulator.", federate_handle);
         throw RTIinternalError("Time regulation not enabled.");
     }
@@ -1456,7 +1527,7 @@ Federation::createRegion(FederateHandle federate,
 // modifyRegion
 void
 Federation::modifyRegion(FederateHandle federate, RegionHandle region,
-			 const vector<Extent> &extents)
+			 const std::vector<Extent> &extents)
     throw (RegionNotKnown, InvalidExtents, SaveInProgress, RestoreInProgress,
 	   RTIinternalError)
 {
@@ -1668,32 +1739,27 @@ Federation::restoreXmlData()
     }
 
     cur = cur->xmlChildrenNode ;
-    list<Federate *>::iterator i ;
+
     bool status ;
     while (cur != NULL) {
         if ((!xmlStrcmp(cur->name, NODE_FEDERATE))) {
-            for (i = begin(); i != end(); i++) {
-                if (!strcmp(
-                        (*i)->getName(),
-                        (char *) xmlGetProp(cur, (const xmlChar*) "name"))) {
+            for (FederateList::iterator i = federates.begin(); i != federates.end(); ++i) {
+                if (!strcmp(i->getName(), (char *) xmlGetProp(cur, (const xmlChar*) "name"))) {
                     // Set federate constrained status
-                    if (strcmp("true", (char *)xmlGetProp(
-                                   cur, (const xmlChar*)"constrained")) == 0)
+                    if (!strcmp("true", (char *) xmlGetProp(cur, (const xmlChar*) "constrained")))
                         status = true ;
                     else
                         status = false ;
 
-                    (*i)->setConstrained(status);
+                    i->setConstrained(status);
 
                     // Set federate regulating status
                     status = !strcmp("true", (char *) xmlGetProp(
                                          cur, (const xmlChar *) "regulator"));
 
-                    (*i)->setRegulator(status);
+                    i->setRegulator(status);
 
-                    (*i)->setHandle(
-                        strtol((char *) xmlGetProp(
-                                   cur, (const xmlChar *) "handle"), 0, 10));
+                    i->setHandle(strtol((char *) xmlGetProp(cur, (const xmlChar *) "handle"), 0, 10));
                     break ;
                 }
             }
@@ -1726,22 +1792,21 @@ Federation::saveXmlData()
 
     xmlNodePtr federate ;
 
-    list<Federate *>::iterator i ;
-    for (i = begin(); i != end(); i++) {
+    for (FederateList::iterator i = federates.begin(); i != federates.end(); ++i) {
         federate = xmlNewChild(federation, NULL, NODE_FEDERATE, NULL);
 
         xmlSetProp(federate,
-                   (const xmlChar *)"name",
-                   (const xmlChar *)(*i)->getName());
+                   (const xmlChar *) "name",
+                   (const xmlChar *) i->getName());
 
-        sprintf(t, "%ld", (*i)->getHandle());
-        xmlSetProp(federate, (const xmlChar *)"handle", (const xmlChar *)t);
+        sprintf(t, "%ld", i->getHandle());
+        xmlSetProp(federate, (const xmlChar *) "handle", (const xmlChar *) t);
 
         xmlSetProp(federate,
                    (const xmlChar *)"constrained", (const xmlChar *)
-                   (((*i)->isConstrained()) ? "true" : "false"));
-        xmlSetProp(federate, (const xmlChar *)"regulator",
-                   (const xmlChar *)(((*i)->isRegulator()) ? "true" : "false"));
+                   ((i->isConstrained()) ? "true" : "false"));
+        xmlSetProp(federate, (const xmlChar *) "regulator",
+                   (const xmlChar *)((i->isRegulator()) ? "true" : "false"));
     }
 
     xmlSetDocCompressMode(doc, 9);
@@ -1757,5 +1822,5 @@ Federation::saveXmlData()
 
 }} // namespace certi/rtig
 
-// $Id: Federation.cc,v 3.45.2.1 2007/01/22 13:54:51 rousse Exp $
+// $Id: Federation.cc,v 3.52 2007/05/03 15:46:31 rousse Exp $
 
