@@ -18,7 +18,7 @@
 // along with this program ; if not, write to the Free Software
 // Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA
 //
-// $Id: FederationsList.cc,v 3.29.2.1 2007/01/22 13:54:51 rousse Exp $
+// $Id: FederationsList.cc,v 3.34 2007/04/20 08:27:07 rousse Exp $
 // ----------------------------------------------------------------------------
 
 #include <config.h>
@@ -26,6 +26,7 @@
 
 using std::list ;
 using std::endl ;
+using std::cout ;
 
 namespace certi {
 namespace rtig {
@@ -126,7 +127,6 @@ FederationsList::searchFederation(Handle handle,
             return j ;
         }
     }
-
     D.Out(pdExcept, "Unknown Federation Handle %d.", handle);
     throw FederationExecutionDoesNotExist("Bad Federation Handle.");
 }
@@ -139,10 +139,11 @@ void FederationsList::createFederation(const char *name,
                                        SocketMC *mc_link)
 #else
     void FederationsList::createFederation(const char *name,
-                                           Handle handle)
+                                           Handle handle,
+                                           const char *FEDid)
 #endif
     throw (FederationExecutionAlreadyExists,
-           CouldNotOpenRID,
+           CouldNotOpenFED,
            ErrorReadingRID,
            MemoryExhausted,
            SecurityError,
@@ -167,16 +168,21 @@ void FederationsList::createFederation(const char *name,
               "CreerFederation catches FederationExecutionDoesNotExist.");
     }
 
-    if (size() >= MAX_FEDERATION)
-        throw RTIinternalError("Too many federation executions.");
-
-
 #ifdef FEDERATION_USES_MULTICAST
     federation = new Federation(name, handle, socketServer, auditFile, mc_link);
 #else
-    federation = new Federation(name, handle, socketServer, auditFile);
-#endif
+    try {
+        federation = new Federation(name, handle, socketServer, auditFile, FEDid);
+        D.Out(pdDebug,"new Federation created.");
+        }
+    catch (RTI::CouldNotOpenFED& e) {
+        cout << e._reason << endl;
+        D.Out(pdInit, "Federation constructor : Could not open FED file.");
+        throw CouldNotOpenFED("Could not open FED file.");
+        }
 
+    
+#endif
     if (federation == NULL)
         throw MemoryExhausted("No memory left for new Federation.");
 
@@ -270,7 +276,8 @@ void FederationsList::info(Handle handle,
     void FederationsList::info(Handle handle,
                                int &nb_federates,
                                int &nb_regulators,
-                               bool &is_syncing)
+                               bool &is_syncing,
+                               char *FED_Filename)
 #endif
     throw (FederationExecutionDoesNotExist, RTIinternalError)
 {
@@ -285,6 +292,7 @@ void FederationsList::info(Handle handle,
     nb_federates = federation->getNbFederates();
     nb_regulators = federation->getNbRegulators();
     is_syncing = federation->isSynchronizing();
+    strcpy(FED_Filename,federation->getFEDid());
 
 #ifdef FEDERATION_USES_MULTICAST
     comm_mc = federation->MCLink ;
@@ -628,11 +636,10 @@ FederationsList::destroyFederation(Handle handle)
 
     // It may throw FederationExecutionDoesNotExist
     int rank = searchFederation(handle, federation);
-
     // It may throw FederatesCurrentlyJoined
     if (federation->empty()) {
         list<Federation *>::iterator i = begin();
-        for (int j = 1 ; i != end() && j <= rank ; j++) {
+        for (int j = 1 ; i != end() && j <= rank ; j++, i++) {
             if (j == rank) {
                 erase(i);
             }
@@ -1264,5 +1271,5 @@ FederationsList::federateRestoreStatus(Handle the_federation,
 
 }} // certi::rtig
 
-// EOF $Id: FederationsList.cc,v 3.29.2.1 2007/01/22 13:54:51 rousse Exp $
+// EOF $Id: FederationsList.cc,v 3.34 2007/04/20 08:27:07 rousse Exp $
 
