@@ -16,6 +16,8 @@
 // License along with this program ; if not, write to the Free Software
 // Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307
 // USA
+//
+// $Id: Message_RW.cc,v 3.30 2007/04/27 16:24:50 erk Exp $
 // ----------------------------------------------------------------------------
 
 #include <config.h>
@@ -73,6 +75,10 @@ Message::readBody(SocketUN *socket)
             // --- No Variable Part, Body not empty ---
 
           case CREATE_FEDERATION_EXECUTION:
+            readFederationName(body);
+            readFEDid(body) ;
+            break ;
+
           case DESTROY_FEDERATION_EXECUTION:
             readFederationName(body);
             break ;
@@ -286,6 +292,12 @@ Message::readBody(SocketUN *socket)
 	  case DDM_MODIFY_REGION:
 	    readExtents(body);
 	    break ;
+
+	  case GET_OBJECT_INSTANCE_HANDLE:
+	  case GET_OBJECT_INSTANCE_NAME:
+            object = body.readLongInt();
+	    readName(body);
+	    break;
 	    
             // -- Default Handler --
 
@@ -488,6 +500,13 @@ Message::readHeader(SocketUN *socket)
         boolean = header.VP.time.mode ;
         break ;
 
+      case GET_OBJECT_INSTANCE_HANDLE:
+      case GET_OBJECT_INSTANCE_NAME:
+	object = header.VP.O_I.handle;
+        handleArraySize = header.VP.O_I.size ;
+        setFederationTime(header.VP.O_I.date);
+        break ;
+
       default:
         D.Out(pdExcept, "Unknown type %d in ReadHeader.", header.type);
         throw RTIinternalError("Message: Received unknown Header type.");
@@ -546,6 +565,12 @@ Message::readTag(MessageBody &body)
     body.readString(tag, MAX_USER_TAG_LENGTH);
 }
 
+// ----------------------------------------------------------------------------
+void
+Message::readFEDid(MessageBody &body)
+{
+    body.readString(FEDid, MAX_FEDFILE_NAME_LENGTH);
+}
 // ----------------------------------------------------------------------------
 //! readValueArray.
 void
@@ -609,6 +634,10 @@ Message::writeBody(SocketUN *socket)
             // --- No Variable Part, Body not empty ---
 
           case CREATE_FEDERATION_EXECUTION:
+            body.writeString(federationName);
+            body.writeString(FEDid);
+            break ;
+
           case DESTROY_FEDERATION_EXECUTION:
             body.writeString(federationName);
             break ;
@@ -819,6 +848,12 @@ Message::writeBody(SocketUN *socket)
 	    writeExtents(body);
 	    break ;
 	    
+	  case GET_OBJECT_INSTANCE_HANDLE:
+	  case GET_OBJECT_INSTANCE_NAME :
+	    body.writeLongInt(object);
+	    body.writeString(name);
+	    break;
+	    
             // -- Default Handler --
 
           default:
@@ -834,7 +869,7 @@ Message::writeBody(SocketUN *socket)
     header.bodySize = body.size() - sizeof(MessageHeader);
 
     // Put the real Body Size in the copy of the Header.
-    ((MessageHeader *) body.getBuffer())->bodySize = header.bodySize ;
+    (reinterpret_cast<MessageHeader *>(body.getBufferRW()))->bodySize = header.bodySize ;
 
     // 3- Write Header to socket, then write Body to socket.
     // socket->send((void *) &Header, sizeof(MessageHeader));
@@ -1073,6 +1108,14 @@ Message::writeHeader(SocketUN *socket)
         header.bodySize = 0 ;
         break ;
 
+      case GET_OBJECT_INSTANCE_HANDLE:
+      case GET_OBJECT_INSTANCE_NAME:
+        header.VP.O_I.handle = object;
+        header.VP.O_I.size = handleArraySize ;
+        header.VP.O_I.date = getFederationTime() ;
+        header.bodySize = 1 ;
+        break ;
+
         // -- Default Handler --
       default:
         D.Out(pdExcept, "Unknown type %d in WriteHeader.", header.type);
@@ -1109,3 +1152,5 @@ Message::writeValueArray(MessageBody &body)
 }
 
 } // namespace certi
+
+// $Id: Message_RW.cc,v 3.30 2007/04/27 16:24:50 erk Exp $
