@@ -16,7 +16,7 @@
 // License along with this program ; if not, write to the Free Software
 // Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA
 //
-// $Id: NetworkMessage.cc,v 3.12.2.1 2007/01/22 13:54:51 rousse Exp $
+// $Id: NetworkMessage.cc,v 3.15 2007/04/20 08:27:07 rousse Exp $
 // ----------------------------------------------------------------------------
 
 #include <config.h>
@@ -35,11 +35,18 @@ namespace certi {
 void
 NetworkMessage::display(const char *s)
 {
-    printf(" --- MESSAGE RESEAU --- %s ---\n", s);
-    printf(" type = %d\n", type);
-    printf(" number = %ld-%d\n", federate, number);
-    printf(" date = %f\n", date);
-    printf(" exception = %d\n", exception);
+    printf(" -- NETWORK MESSAGE - %s -", s);
+    if ( type == CREATE_FEDERATION_EXECUTION )
+        printf("CREATE_FEDERATION_EXECUTION : federation %s : filename %s\n",federationName,FEDid);
+    else if (type == JOIN_FEDERATION_EXECUTION )
+        printf("JOIN_FEDERATION_EXECUTION : federation %s : federate %s \n",federationName,federateName);
+    else if (type == GET_FED_FILE ) 
+        printf("GET_FED_FILE : number %ld\n",number) ;
+    else
+        printf(" type = %d\n", type);
+    printf(" number = %ld-%d", federate, number);
+    printf(" date = %f ", date);
+    printf(" exception = %d ", exception);
     printf(" ObjectHandle = %ld\n", objectClass);
     printf(" interactionClass= %ld\n", interactionClass);
     printf(" object = %ld\n", object);
@@ -58,6 +65,7 @@ NetworkMessage::NetworkMessage()
     federationName[0] = '\0' ;
     federateName[0] = '\0' ;
     label[0] = '\0' ;
+    FEDid[0] = '\0' ;
 
     bestEffortPeer = -1 ;
     bestEffortAddress = 0 ;
@@ -269,6 +277,24 @@ NetworkMessage::readFederateName(MessageBody &body)
     body.readString(federateName, MAX_FEDERATE_NAME_LENGTH);
 }
 
+// ----------------------------------------------------------------------------
+// setFEDid
+//
+void
+NetworkMessage::setFEDid(const char *NewFEDid)
+{
+    if (strlen(NewFEDid) > MAX_FEDFILE_NAME_LENGTH)
+        throw ValueLengthExceeded("FEDFILE name too long to fit in Network Message.");
+
+    strcpy(FEDid, NewFEDid);
+}
+
+// ----------------------------------------------------------------------------
+void
+NetworkMessage::readFEDid(MessageBody &body)
+{
+    body.readString(FEDid, MAX_FEDFILE_NAME_LENGTH);
+}
 } // namespace certi
 
-// $Id: NetworkMessage.cc,v 3.12.2.1 2007/01/22 13:54:51 rousse Exp $
+// $Id: NetworkMessage.cc,v 3.15 2007/04/20 08:27:07 rousse Exp $
