@@ -16,7 +16,7 @@
 // License along with this program ; if not, write to the Free Software
 // Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA
 //
-// $Id: NetworkMessage_RW.cc,v 3.20.2.1 2007/01/22 13:54:51 rousse Exp $
+// $Id: NetworkMessage_RW.cc,v 3.24 2007/04/27 16:24:50 erk Exp $
 // ----------------------------------------------------------------------------
 
 #include <config.h>
@@ -25,6 +25,8 @@
 #include "PrettyDebug.hh"
 
 using std::vector ;
+using std::endl;
+using std::cout;
 
 namespace certi {
 
@@ -46,6 +48,18 @@ NetworkMessage::readBody(Socket *socket)
 
     // 3. Read informations from Message Body according to message type.
     switch(Header.type) {
+      case GET_FED_FILE:
+        number = body.readShortInt();
+        unsigned short nb;      
+        nb = body.readShortInt();
+        body.readBlock(FEDid,nb);
+        if ( number >= 1 )  // open (0) and close (0) no more information
+            {
+            ValueArray[0].length = body.readLongInt();
+            body.readBlock(ValueArray[0].value, ValueArray[0].length) ;
+	    }
+	break ;
+            
       case UPDATE_ATTRIBUTE_VALUES:
       case REFLECT_ATTRIBUTE_VALUES:
 	object = body.readLongInt();
@@ -71,6 +85,10 @@ NetworkMessage::readBody(Socket *socket)
 	break ;
 	
       case CREATE_FEDERATION_EXECUTION:
+	readFederationName(body);
+	readFEDid(body);
+	break ;
+
       case DESTROY_FEDERATION_EXECUTION:
 	readFederationName(body);
 	break ;
@@ -303,6 +321,7 @@ NetworkMessage::readHeader(Socket *socket)
       case DDM_SUBSCRIBE_INTERACTION:
       case DDM_UNSUBSCRIBE_INTERACTION:
       case DDM_REGISTER_OBJECT:
+      case GET_FED_FILE:
 	break ;
 
       case SET_TIME_REGULATING:
@@ -392,10 +411,24 @@ NetworkMessage::writeBody(Socket *socket)
     // make a single Socket->Emettre call while sending both.
     // WARNING: As the body size is not known yet, we will have to
     // change it in the copy also!
-    body.writeBlock((char *) &Header, sizeof(HeaderStruct));
+    body.writeBlock(reinterpret_cast<char *>(&Header), sizeof(HeaderStruct));
+    
+    D.Out(pdTrace, "HeaderStruct size is : <%d> out of <%d> bytes MAX in body\n",
+	  sizeof(HeaderStruct),BUFFER_SIZE_DEFAULT);
 
     // 1- Prepare body Structure according to Message type
     switch(Header.type) {
+      case GET_FED_FILE:
+        body.writeShortInt(number);
+        body.writeShortInt(strlen(FEDid));
+        body.writeBlock(FEDid,strlen(FEDid));
+        if ( number >= 1 )  // open (0) and close (0) no more information
+            {
+            body.writeLongInt(ValueArray[0].length);
+            body.writeBlock(ValueArray[0].value, ValueArray[0].length);
+            }
+      break;
+
       case UPDATE_ATTRIBUTE_VALUES:
       case REFLECT_ATTRIBUTE_VALUES:
 	body.writeLongInt(object);
@@ -425,6 +458,10 @@ NetworkMessage::writeBody(Socket *socket)
 	// -- No Variable Part --
 
       case CREATE_FEDERATION_EXECUTION:
+	body.writeString(federationName);
+	body.writeString(FEDid);
+	break ;
+
       case DESTROY_FEDERATION_EXECUTION:
 	body.writeString(federationName);
 	break ;
@@ -579,8 +616,8 @@ NetworkMessage::writeBody(Socket *socket)
     Header.bodySize = body.size() - sizeof(HeaderStruct);
 
     // Put the real body Size in the copy of the Header.
-    ((HeaderStruct *) body.getBuffer())->bodySize = Header.bodySize ;
-
+    (reinterpret_cast<HeaderStruct *>(body.getBufferRW()))->bodySize = Header.bodySize ;
+    D.Out(pdTrace,"Sending MessageBody of size <%d>",body.size());
     socket->send(body.getBuffer(), body.size());
 }
 
@@ -682,6 +719,7 @@ NetworkMessage::writeHeader(Socket *socket)
       case DDM_SUBSCRIBE_INTERACTION:
       case DDM_UNSUBSCRIBE_INTERACTION:	
       case DDM_REGISTER_OBJECT:
+      case GET_FED_FILE:
 	Header.bodySize = 1 ;
 	break ;
 
@@ -799,4 +837,4 @@ NetworkMessage::writeHeader(Socket *socket)
 
 } // namespace certi
 
-// $Id: NetworkMessage_RW.cc,v 3.20.2.1 2007/01/22 13:54:51 rousse Exp $
+// $Id: NetworkMessage_RW.cc,v 3.24 2007/04/27 16:24:50 erk Exp $
