@@ -112,11 +112,11 @@
 
 
 /* Copy the first part of user declarations.  */
-#line 1 "syntax.yy"
+#line 1 "../../Sources/Savannah/certi/libCERTI/syntax.yy"
 
 // ----------------------------------------------------------------------------
 // CERTI - HLA RunTime Infrastructure
-// Copyright (C) 2003  Benot Brhole
+// Copyright (C) 2003  ONERA
 //
 // This file is part of CERTI-libCERTI
 //
@@ -135,7 +135,7 @@
 // Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307
 // USA
 //
-// $Id: syntax.yy,v 3.2 2003/11/13 10:45:56 breholee Exp $
+// $Id: syntax.yy,v 3.3 2006/03/09 19:54:28 breholee Exp $
 // ----------------------------------------------------------------------------
 
 #include "fed.hh"
@@ -1487,117 +1487,117 @@ yyreduce:
   switch (yyn)
     {
         case 2:
-#line 71 "syntax.yy"
+#line 71 "../../Sources/Savannah/certi/libCERTI/syntax.yy"
     { certi::fedparser::startFed(); }
     break;
 
   case 3:
-#line 77 "syntax.yy"
+#line 77 "../../Sources/Savannah/certi/libCERTI/syntax.yy"
     { certi::fedparser::endFed(); }
     break;
 
   case 5:
-#line 81 "syntax.yy"
+#line 81 "../../Sources/Savannah/certi/libCERTI/syntax.yy"
     { certi::fedparser::addFederation(); }
     break;
 
   case 7:
-#line 85 "syntax.yy"
+#line 85 "../../Sources/Savannah/certi/libCERTI/syntax.yy"
     { certi::fedparser::addFedVersion(); }
     break;
 
   case 13:
-#line 97 "syntax.yy"
+#line 97 "../../Sources/Savannah/certi/libCERTI/syntax.yy"
     { certi::fedparser::startFederate(); }
     break;
 
   case 14:
-#line 98 "syntax.yy"
+#line 98 "../../Sources/Savannah/certi/libCERTI/syntax.yy"
     { certi::fedparser::endFederate(); }
     break;
 
   case 16:
-#line 102 "syntax.yy"
+#line 102 "../../Sources/Savannah/certi/libCERTI/syntax.yy"
     { certi::fedparser::startSpaces(); }
     break;
 
   case 17:
-#line 103 "syntax.yy"
+#line 103 "../../Sources/Savannah/certi/libCERTI/syntax.yy"
     { certi::fedparser::end(); }
     break;
 
   case 23:
-#line 115 "syntax.yy"
+#line 115 "../../Sources/Savannah/certi/libCERTI/syntax.yy"
     { certi::fedparser::startSpace(); }
     break;
 
   case 24:
-#line 116 "syntax.yy"
+#line 116 "../../Sources/Savannah/certi/libCERTI/syntax.yy"
     { certi::fedparser::endSpace(); }
     break;
 
   case 30:
-#line 128 "syntax.yy"
+#line 128 "../../Sources/Savannah/certi/libCERTI/syntax.yy"
     { certi::fedparser::addDimension(); }
     break;
 
   case 32:
-#line 132 "syntax.yy"
+#line 132 "../../Sources/Savannah/certi/libCERTI/syntax.yy"
     { certi::fedparser::startObjects(); }
     break;
 
   case 33:
-#line 133 "syntax.yy"
+#line 133 "../../Sources/Savannah/certi/libCERTI/syntax.yy"
     { certi::fedparser::end(); }
     break;
 
   case 39:
-#line 145 "syntax.yy"
+#line 145 "../../Sources/Savannah/certi/libCERTI/syntax.yy"
     { certi::fedparser::startObject(); }
     break;
 
   case 40:
-#line 146 "syntax.yy"
+#line 146 "../../Sources/Savannah/certi/libCERTI/syntax.yy"
     { certi::fedparser::endObject(); }
     break;
 
   case 51:
-#line 163 "syntax.yy"
+#line 163 "../../Sources/Savannah/certi/libCERTI/syntax.yy"
     { certi::fedparser::addAttribute(); }
     break;
 
   case 53:
-#line 167 "syntax.yy"
+#line 167 "../../Sources/Savannah/certi/libCERTI/syntax.yy"
     { certi::fedparser::startInteractions(); }
     break;
 
   case 54:
-#line 168 "syntax.yy"
+#line 168 "../../Sources/Savannah/certi/libCERTI/syntax.yy"
     { certi::fedparser::end(); }
     break;
 
   case 60:
-#line 180 "syntax.yy"
+#line 180 "../../Sources/Savannah/certi/libCERTI/syntax.yy"
     { certi::fedparser::startInteraction(); }
     break;
 
   case 61:
-#line 181 "syntax.yy"
+#line 181 "../../Sources/Savannah/certi/libCERTI/syntax.yy"
     { certi::fedparser::endInteraction(); }
     break;
 
   case 71:
-#line 197 "syntax.yy"
+#line 197 "../../Sources/Savannah/certi/libCERTI/syntax.yy"
     { certi::fedparser::addParameter(); }
     break;
 
   case 73:
-#line 201 "syntax.yy"
+#line 201 "../../Sources/Savannah/certi/libCERTI/syntax.yy"
     { certi::fedparser::addInteractionSecurityLevel(); }
     break;
 
   case 75:
-#line 205 "syntax.yy"
+#line 205 "../../Sources/Savannah/certi/libCERTI/syntax.yy"
     { certi::fedparser::addObjectSecurityLevel(); }
     break;
 
@@ -1817,7 +1817,7 @@ yyreturn:
 }
 
 
-#line 208 "syntax.yy"
+#line 208 "../../Sources/Savannah/certi/libCERTI/syntax.yy"
 
 
 int yyerror(char *s) {
